@@ -33,8 +33,9 @@ TESSERACT_COMMON_IGNORE_WARNINGS_POP
 
 namespace tinyxml2
 {
-class XMLElement;
-}
+class XMLElement;  // NOLINT
+class XMLDocument;
+}  // namespace tinyxml2
 namespace tesseract_geometry
 {
 class Cone;
@@ -49,6 +50,9 @@ namespace tesseract_urdf
  */
 std::shared_ptr<tesseract_geometry::Cone> parseCone(const tinyxml2::XMLElement* xml_element, int version);
 
+tinyxml2::XMLElement* writeCone(const std::shared_ptr<const tesseract_geometry::Cone>& cone,
+                                tinyxml2::XMLDocument& doc);
+
 }  // namespace tesseract_urdf
 
 #endif  // TESSERACT_URDF_CONE_H
