@@ -34,8 +34,9 @@ TESSERACT_COMMON_IGNORE_WARNINGS_POP
 
 namespace tinyxml2
 {
-class XMLElement;
-}
+class XMLElement;  // NOLINT
+class XMLDocument;
+}  // namespace tinyxml2
 
 namespace tesseract_urdf
 {
@@ -47,6 +48,8 @@ namespace tesseract_urdf
  */
 Eigen::Isometry3d parseOrigin(const tinyxml2::XMLElement* xml_element, int version);
 
+tinyxml2::XMLElement* writeOrigin(const Eigen::Isometry3d& origin, tinyxml2::XMLDocument& doc);
+
 }  // namespace tesseract_urdf
 
 #endif  // TESSERACT_URDF_ORIGIN_H
