@@ -6,12 +6,12 @@ TESSERACT_COMMON_IGNORE_WARNINGS_PUSH
 TESSERACT_COMMON_IGNORE_WARNINGS_POP
 
 #include <tesseract_urdf/urdf_parser.h>
+#include <tesseract_support/tesseract_support_resource_locator.h>
 #include "tesseract_urdf_common_unit.h"
 
 TEST(TesseractURDFUnit, parse_urdf)  // NOLINT
 {
-  std::shared_ptr<tesseract_scene_graph::SimpleResourceLocator> resource_locator =
-      std::make_shared<tesseract_scene_graph::SimpleResourceLocator>(locateResource);
+  tesseract_common::TesseractSupportResourceLocator resource_locator;
   {
     std::string str =
         R"(<robot name="test" extra="0 0 0">
@@ -82,7 +82,7 @@ TEST(TesseractURDFUnit, parse_urdf)  // NOLINT
              <link name="l1"/>
              <link name="l2"/>
            </robot>)";
-    EXPECT_ANY_THROW(tesseract_urdf::parseURDFString(str, resource_locator));
+    EXPECT_ANY_THROW(tesseract_urdf::parseURDFString(str, resource_locator));  // NOLINT
   }
 
   {
@@ -105,7 +105,7 @@ TEST(TesseractURDFUnit, parse_urdf)  // NOLINT
              <link name="l1"/>
              <link name="l2"/>
            </robot>)";
-    EXPECT_ANY_THROW(tesseract_urdf::parseURDFString(str, resource_locator));
+    EXPECT_ANY_THROW(tesseract_urdf::parseURDFString(str, resource_locator));  // NOLINT
   }
 
   {
@@ -124,7 +124,7 @@ TEST(TesseractURDFUnit, parse_urdf)  // NOLINT
              <link name="l1"/>
              <link name="l3"/>
            </robot>)";
-    EXPECT_ANY_THROW(tesseract_urdf::parseURDFString(str, resource_locator));
+    EXPECT_ANY_THROW(tesseract_urdf::parseURDFString(str, resource_locator));  // NOLINT
   }
 
   {
@@ -144,7 +144,7 @@ TEST(TesseractURDFUnit, parse_urdf)  // NOLINT
              <link name="l2"/>
              <link name="l3"/>
            </robot>)";
-    EXPECT_ANY_THROW(tesseract_urdf::parseURDFString(str, resource_locator));
+    EXPECT_ANY_THROW(tesseract_urdf::parseURDFString(str, resource_locator));  // NOLINT
   }
 
   {
@@ -163,7 +163,7 @@ TEST(TesseractURDFUnit, parse_urdf)  // NOLINT
              <link name="l1"/>
              <link name="l2"/>
            </robot>)";
-    EXPECT_ANY_THROW(tesseract_urdf::parseURDFString(str, resource_locator));
+    EXPECT_ANY_THROW(tesseract_urdf::parseURDFString(str, resource_locator));  // NOLINT
   }
 
   {
@@ -183,7 +183,7 @@ TEST(TesseractURDFUnit, parse_urdf)  // NOLINT
              <link name="l2"/>
              <link name="l1"/>
            </robot>)";
-    EXPECT_ANY_THROW(tesseract_urdf::parseURDFString(str, resource_locator));
+    EXPECT_ANY_THROW(tesseract_urdf::parseURDFString(str, resource_locator));  // NOLINT
   }
 
   {
@@ -202,7 +202,7 @@ TEST(TesseractURDFUnit, parse_urdf)  // NOLINT
              <link name="l1"/>
              <link name="l2"/>
            </robot>)";
-    EXPECT_ANY_THROW(tesseract_urdf::parseURDFString(str, resource_locator));
+    EXPECT_ANY_THROW(tesseract_urdf::parseURDFString(str, resource_locator));  // NOLINT
   }
 
   {
@@ -226,7 +226,7 @@ TEST(TesseractURDFUnit, parse_urdf)  // NOLINT
              <link name="l2"/>
              <link name="l3"/>
            </robot>)";
-    EXPECT_ANY_THROW(tesseract_urdf::parseURDFString(str, resource_locator));
+    EXPECT_ANY_THROW(tesseract_urdf::parseURDFString(str, resource_locator));  // NOLINT
   }
 
   {
@@ -247,8 +247,7 @@ TEST(TesseractURDFUnit, parse_urdf)  // NOLINT
 
 TEST(TesseractURDFUnit, parse_urdf_with_available_materials)  // NOLINT
 {
-  std::shared_ptr<tesseract_scene_graph::SimpleResourceLocator> resource_locator =
-      std::make_shared<tesseract_scene_graph::SimpleResourceLocator>(locateResource);
+  tesseract_common::TesseractSupportResourceLocator resource_locator;
   {
     std::string str =
         R"(<robot name="test" extra="0 0 0">
@@ -364,7 +363,7 @@ TEST(TesseractURDFUnit, parse_urdf_with_available_materials)  // NOLINT
                </visual>
              </link>
            </robot>)";
-    EXPECT_ANY_THROW(tesseract_urdf::parseURDFString(str, resource_locator));
+    EXPECT_ANY_THROW(tesseract_urdf::parseURDFString(str, resource_locator));  // NOLINT
   }
 
   {
@@ -414,9 +413,8 @@ TEST(TesseractURDFUnit, LoadURDFUnit)  // NOLINT
 
   std::string urdf_file = std::string(TESSERACT_SUPPORT_DIR) + "/urdf/lbr_iiwa_14_r820.urdf";
 
-  tesseract_scene_graph::ResourceLocator::Ptr locator =
-      std::make_shared<tesseract_scene_graph::SimpleResourceLocator>(locateResource);
-  SceneGraph::Ptr g = tesseract_urdf::parseURDFFile(urdf_file, locator);
+  tesseract_common::TesseractSupportResourceLocator locator;
+  auto g = tesseract_urdf::parseURDFFile(urdf_file, locator);
 
   EXPECT_TRUE(g->getJoints().size() == 9);
   EXPECT_TRUE(g->getLinks().size() == 10);
@@ -427,16 +425,98 @@ TEST(TesseractURDFUnit, LoadURDFUnit)  // NOLINT
   g->saveDOT(tesseract_common::getTempPath() + "tesseract_urdf_import.dot");
 
   // Get Shortest Path
-  SceneGraph::Path path = g->getShortestPath("link_1", "link_4");
+  auto path = g->getShortestPath("link_1", "link_4");
 
   std::cout << path << std::endl;
-  EXPECT_TRUE(path.first.size() == 4);
-  EXPECT_TRUE(std::find(path.first.begin(), path.first.end(), "link_1") != path.first.end());
-  EXPECT_TRUE(std::find(path.first.begin(), path.first.end(), "link_2") != path.first.end());
-  EXPECT_TRUE(std::find(path.first.begin(), path.first.end(), "link_3") != path.first.end());
-  EXPECT_TRUE(std::find(path.first.begin(), path.first.end(), "link_4") != path.first.end());
-  EXPECT_TRUE(path.second.size() == 3);
-  EXPECT_TRUE(std::find(path.second.begin(), path.second.end(), "joint_a2") != path.second.end());
-  EXPECT_TRUE(std::find(path.second.begin(), path.second.end(), "joint_a3") != path.second.end());
-  EXPECT_TRUE(std::find(path.second.begin(), path.second.end(), "joint_a4") != path.second.end());
+  EXPECT_TRUE(path.links.size() == 4);
+  EXPECT_TRUE(std::find(path.links.begin(), path.links.end(), "link_1") != path.links.end());
+  EXPECT_TRUE(std::find(path.links.begin(), path.links.end(), "link_2") != path.links.end());
+  EXPECT_TRUE(std::find(path.links.begin(), path.links.end(), "link_3") != path.links.end());
+  EXPECT_TRUE(std::find(path.links.begin(), path.links.end(), "link_4") != path.links.end());
+  EXPECT_TRUE(path.joints.size() == 3);
+  EXPECT_TRUE(std::find(path.joints.begin(), path.joints.end(), "joint_a2") != path.joints.end());
+  EXPECT_TRUE(std::find(path.joints.begin(), path.joints.end(), "joint_a3") != path.joints.end());
+  EXPECT_TRUE(std::find(path.joints.begin(), path.joints.end(), "joint_a4") != path.joints.end());
+}
+
+TEST(TesseractURDFUnit, write_urdf)  // NOLINT
+{
+  {  // trigger nullptr input
+    tesseract_scene_graph::SceneGraph::Ptr sg = nullptr;
+    bool success = true;
+    try
+    {
+      tesseract_urdf::writeURDFFile(sg, "/tmp/", "urdf0.urdf");
+    }
+    catch (...)
+    {
+      success = false;
+    }
+
+    EXPECT_FALSE(success);
+  }
+
+  {  // Successful run
+    tesseract_scene_graph::SceneGraph::Ptr sg = std::make_shared<tesseract_scene_graph::SceneGraph>();
+
+    // Add 2 links
+    tesseract_scene_graph::Link::Ptr link_0 = std::make_shared<tesseract_scene_graph::Link>("link_0");
+    tesseract_scene_graph::Link::Ptr link_1 = std::make_shared<tesseract_scene_graph::Link>("link_1");
+    sg->addLink(*link_0);
+    sg->addLink(*link_1);
+
+    // Add joint
+    tesseract_scene_graph::Joint::Ptr joint_0 = std::make_shared<tesseract_scene_graph::Joint>("joint_0");
+    joint_0->type = tesseract_scene_graph::JointType::FIXED;
+    joint_0->parent_link_name = link_0->getName();
+    joint_0->child_link_name = link_1->getName();
+    sg->addJoint(*joint_0);
+
+    bool success = true;
+    try
+    {
+      tesseract_urdf::writeURDFFile(sg, "/tmp/", "urdf1.urdf");
+    }
+    catch (...)
+    {
+      success = false;
+    }
+
+    EXPECT_TRUE(success);
+  }
+
+  /* Triggering a bad link is actually very difficult.  The addLink function uses Link::clone(), which
+   * dereferences all the collision & visual pointers, causing a segfault if the link was ill-formed.
+   * This should probably get changed to throwing an exception if it is nullptr.
+  { // Trigger Bad Link
+    tesseract_scene_graph::SceneGraph::Ptr sg = std::make_shared<tesseract_scene_graph::SceneGraph>();
+
+    // Add 2 links
+    tesseract_scene_graph::Link::Ptr link_0 = std::make_shared<tesseract_scene_graph::Link>("link_0");
+    link_0->visual.resize(1);
+    link_0->visual[0] = nullptr;  // Bad visual geometry to cause write failure in link
+    tesseract_scene_graph::Link::Ptr link_1 = std::make_shared<tesseract_scene_graph::Link>("link_1");
+    sg->addLink(*link_0);
+    sg->addLink(*link_1);
+
+    // Add joint
+    tesseract_scene_graph::Joint::Ptrros-industrial joint_0 = std::make_shared<tesseract_scene_graph::Joint>("joint_0");
+    joint_0->type = tesseract_scene_graph::JointType::FIXED;
+    joint_0->parent_link_name = link_0->getName();
+    joint_0->child_link_name = link_1->getName();
+    sg->addJoint(*joint_0);
+
+    bool success = true;
+    try
+    {
+      tesseract_urdf::writeURDFFile(sg, "/tmp/", "urdf3.urdf");
+    }
+    catch (...)
+    {
+      success = false;
+    }
+
+    EXPECT_FALSE(success);
+  }
+  */
 }
